@@ -49,6 +49,8 @@ class TicketService(MetricsService):
 class AnyContainer(DependencyContainer):
     database = Dependency(instance_of=DatabaseResource, default=DatabaseResource(modules=[__name__]))
     ticket_service = TicketService()
+    file_repository: Dependency[OsFilesResource] = Dependency(default=OsFilesResource(Path("applied_files")))
+    data_store: Dependency[InMemoryDictStore] = Dependency(default=InMemoryDictStore())
 
 
 class TestAddonLoader(AddonsLoader):
@@ -70,9 +72,8 @@ if __name__ == '__main__':
     file_repo = OsFilesResource(Path("../applied_files"))
     store = InMemoryDictStore()
     # addon_loader = TestAddonLoader(addons_dir_path=Path("plugins"), files_repo=file_repo, store=store)
-    container = AnyContainer(app_config=app_config, data_store=store, file_repository=file_repo,
-                             )
-
+    container: AnyContainer = AnyContainer(app_config=app_config, data_store=store, file_repository=file_repo,
+                                           )
     scheduler = TaskScheduler(executors={"default": AsyncIOExecutor()})
     dispatcher = IDispatcher(scheduler=scheduler)
     app = App(dependency_container=container, dispatcher=dispatcher)
