@@ -9,7 +9,7 @@ class ApiAddonsService(Service):
         self.addons_loader = addons_loader
 
     async def add_new_middleware(self, filename: str):
-        await self.addons_loader.add_new_middleware(filename)
+        await self.addons_loader.add_new_addon(filename)
 
     async def delete_middleware(self, filename: str):
-        await self.addons_loader.delete_middleware(filename)
+        await self.addons_loader.delete_addon(filename)
