@@ -9,7 +9,7 @@ from web_foundation.extentions.addons.addon_loader import AddonsLoader
 from web_foundation.kernel.dependency import Dependency
 from web_foundation.kernel.messaging.channel import IChannel
 from web_foundation.kernel.stage import ListenerRegistrator
-from web_foundation.resources.files.interface import FilesResource
+from web_foundation.resources.files.interface import FilesResourceInterface
 from web_foundation.resources.resource import Resource
 from web_foundation.resources.stores.interface import DataStore
 from web_foundation.utils.helpers import in_obj_classes, in_obj_subcls_of_dependencies
@@ -18,7 +18,7 @@ from web_foundation.utils.helpers import in_obj_classes, in_obj_subcls_of_depend
 class DependencyContainer:
     app_config: Dependency[GenericConfig] = Dependency(instance_of=BaseModel)
     data_store: Dependency[DataStore] = Dependency(instance_of=DataStore)
-    file_repository: Dependency[FilesResource] = Dependency(instance_of=FilesResource)
+    file_repository: Dependency[FilesResourceInterface] = Dependency(instance_of=FilesResourceInterface)
     addon_loader: Dependency[AddonsLoader] = Dependency(instance_of=AddonsLoader)
 
     def __init__(self, **kwargs):
@@ -51,7 +51,4 @@ class DependencyContainer:
         for resource in self.resources:
             await resource.shutdown()
 
-    def services(self):
-        return
-
 GenericDependencyContainer = TypeVar("GenericDependencyContainer", bound=DependencyContainer)
