@@ -1,12 +1,14 @@
-from typing import Any
+from typing import Any, TypeVar, Generic
 
 from web_foundation.config import AppConf
 from web_foundation.kernel.messaging.channel import IChannel
 from web_foundation.kernel.stage import ListenerRegistrator
 
+GenericCommunicator = TypeVar("GenericCommunicator")
 
-class Resource:
-    _communicator: Any | None
+
+class Resource(Generic[GenericCommunicator]):
+    _communicator: GenericCommunicator | None
     _channel: IChannel | None
     _inited: bool
     _config: AppConf
@@ -14,7 +16,8 @@ class Resource:
     def __init__(self, *args, **kwargs):
         self._inited = False
 
-    async def init(self, config: AppConf, channel: IChannel | None = None, communicator: Any | None = None, *args,
+    async def init(self, config: AppConf, channel: IChannel | None = None,
+                   communicator: GenericCommunicator | None = None, *args,
                    **kwargs) -> None:
         self._config = config
         self._channel = channel
